# MAINTAINERS

Following is the current list of maintainers on this project.

The maintainers are listed in alphabetical order.

- Alessandro Pomponio
  ([AlessandroPomponio](https://github.com/AlessandroPomponio))
- Christian Pinto ([christian-pinto](https://github.com/christian-pinto))
- Daniele Lotito ([danielelotito](https://github.com/danielelotito))
- Michael Johnston ([michael-johnston](https://github.com/michael-johnston))
- Michele Gazzetti ([mgazz](https://github.com/mgazz))
- Srikumar Venugopal ([srikumar003](https://github.com/srikumar003))
- Vassilis Vassiliadis
  ([VassilisVassiliadis](https://github.com/VassilisVassiliadis))

---

We extend a sincere thank you to our colleagues who contributed to ado before it
was open sourced:

- Boris Lublinsky ([blublinsky](https://github.com/blublinsky))
- Burkhard Ringlein ([bringlein](https://github.com/bringlein))
- Gabriela Pinheiro Costa ([GabrielaPC](https://github.com/GabrielaPC))
- Raphael Melo Thiago ([raphael-melo](https://github.com/raphael-melo))
- Renato Maia ([renatomaia](https://github.com/renatomaia))
